@@ -42,11 +42,10 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'CONFIGURE_LDFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
                              '-flto-partition=none -g',
- 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' "
-                "'--with-computed-gotos' '--enable-optimizations' '--with-lto' "
-                "'--enable-ipv6' '--with-system-expat' "
-                "'--with-dbmliborder=gdbm:ndbm' '--with-system-ffi' "
-                "'--with-system-libmpdec' "
+ 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-computed-gotos' "
+                "'--enable-optimizations' '--with-lto' '--enable-ipv6' "
+                "'--with-system-expat' '--with-dbmliborder=gdbm:ndbm' "
+                "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe "
                 "-fstack-protector-strong -fno-plt' "
